==> tauri-plugin-graphql-0.2.1.crate: tauri-plugin-graphql-0.2.1/packages/urql/CHANGELOG.md <==
# Changelog

## \[0.2.2]

- Update dependency `@tauri-apps/api` to `1.0.0-rc.4`
  - [5e68e7b](https://www.github.com/your-org/tauri-plugin-graphql/commit/5e68e7b7676f51bea1212a62f824708297e2df57) Create update-tauri-api.md on 2022-04-27

## \[0.2.1]

- Fix readme copy\&paste issue
  - [a9a3fed](https://www.github.com/your-org/tauri-plugin-graphql/commit/a9a3fedc958cd33b756d9613526cc555bff4e2f5) fix readme copy paste issue on 2022-04-02
- Update README.md
  - [0ebf8c6](https://www.github.com/your-org/tauri-plugin-graphql/commit/0ebf8c636834d4750b4b9c84eb575e140f7d6fd2) Create fix-update-readme.md on 2022-04-02

## \[0.2.0]

- Add support for GraphQL subscriptions. Subscriptions provide a type-safe way to model real-time state changes. This feature is currently gated by the `subscriptions` flag but will be enabled by default in a future release.
  - [d73c988](https://www.github.com/your-org/tauri-plugin-graphql/commit/d73c988230b5616dd3ce77c782a39cdfd2d10a8c) add changefiles on 2022-04-01
- **Breaking Change**: The `tauriExchange` has been renamed and deprecated and will be removed in a future release. Please use `invokeExchange` instead.
  - [d73c988](https://www.github.com/your-org/tauri-plugin-graphql/commit/d73c988230b5616dd3ce77c782a39cdfd2d10a8c) add changefiles on 2022-04-01

## \[0.1.1]

- Npm publish hotfix
  - [5ccffc3](https://www.github.com/your-org/tauri-plugin-graphql/commit/5ccffc37efa170db92a260ab6bd89e5fe40b625b) npm publish hotfix on 2022-03-30

## \[0.1.0]

- Initial release.
  - [691ebc1](https://www.github.com/your-org/tauri-plugin-graphql/commit/691ebc16f90aba3f0d33ca6b2dadb0552b098239) initial commit on 2022-03-30
  - [85e7726](https://www.github.com/your-org/tauri-plugin-graphql/commit/85e7726dd7e55b70c7bc739835d4ff08685fe220) update changefile on 2022-03-30

==> tauri-plugin-graphql-0.2.2.crate: tauri-plugin-graphql-0.2.2/packages/urql/CHANGELOG.md <==
# Changelog

## \[0.2.3]

- Update dependencies
  - [7c8a65d](https://www.github.com/your-org/tauri-plugin-graphql/commit/7c8a65d2ccdf9ea8f0cced2fc8734ba9aec9d1c0) Create update-deps.md on 2022-05-11

## \[0.2.2]

- Update dependency `@tauri-apps/api` to `1.0.0-rc.4`
  - [5e68e7b](https://www.github.com/your-org/tauri-plugin-graphql/commit/5e68e7b7676f51bea1212a62f824708297e2df57) Create update-tauri-api.md on 2022-04-27

## \[0.2.1]

- Fix readme copy\&paste issue
  - [a9a3fed](https://www.github.com/your-org/tauri-plugin-graphql/commit/a9a3fedc958cd33b756d9613526cc555bff4e2f5) fix readme copy paste issue on 2022-04-02
- Update README.md
  - [0ebf8c6](https://www.github.com/your-org/tauri-plugin-graphql/commit/0ebf8c636834d4750b4b9c84eb575e140f7d6fd2) Create fix-update-readme.md on 2022-04-02

## \[0.2.0]

- Add support for GraphQL subscriptions. Subscriptions provide a type-safe way to model real-time state changes. This feature is currently gated by the `subscriptions` flag but will be enabled by default in a future release.
  - [d73c988](https://www.github.com/your-org/tauri-plugin-graphql/commit/d73c988230b5616dd3ce77c782a39cdfd2d10a8c) add changefiles on 2022-04-01
- **Breaking Change**: The `tauriExchange` has been renamed and deprecated and will be removed in a future release. Please use `invokeExchange` instead.
  - [d73c988](https://www.github.com/your-org/tauri-plugin-graphql/commit/d73c988230b5616dd3ce77c782a39cdfd2d10a8c) add changefiles on 2022-04-01

## \[0.1.1]

- Npm publish hotfix
  - [5ccffc3](https://www.github.com/your-org/tauri-plugin-graphql/commit/5ccffc37efa170db92a260ab6bd89e5fe40b625b) npm publish hotfix on 2022-03-30

## \[0.1.0]

- Initial release.
  - [691ebc1](https://www.github.com/your-org/tauri-plugin-graphql/commit/691ebc16f90aba3f0d33ca6b2dadb0552b098239) initial commit on 2022-03-30
  - [85e7726](https://www.github.com/your-org/tauri-plugin-graphql/commit/85e7726dd7e55b70c7bc739835d4ff08685fe220) update changefile on 2022-03-30
